window.Gleam.initSearch([{"doc":"gleam_gun","title":"gleam_gun","content":"# Gleam Gun\n\nGleam bindings to [gun][gun], the Erlang HTTP/1.1, HTTP/2 and Websocket client.\nFork of [nerf][https://github.com/lpil/nerf] that adds connection options.\n\n[gun]: https://hex.pm/packages/gun \n\nCurrently this library is very basic and only supports a portion of the\nwebsocket API, and TLS is not verified!\n\n## Usage\n\nThis package can be added to your Gleam project like so.\n\n```sh\ngleam add gleam_gun\n```\n\nThen use it in your Gleam application.\n\n```rust\nimport gleam_gun/websocket\nimport gleam/erlang\nimport gleam/erlang/atom\n\npub fn main() {\n  // Set connection options\n  let conn_opts = [\n    websocket.Transport(atom.create_from_string(&quot;tls&quot;)),\n    websocket.TransportOpts([websocket.Verify(atom.create_from_string(&quot;verify_none&quot;))]),\n  ]\n  // Connect\n  assert Ok(conn) = websocket.connect(&quot;example.com&quot;, &quot;/ws&quot;, 8080, [], conn_opts)\n\n  // Send some messages\n  websocket.send(conn, &quot;Hello&quot;)\n  websocket.send(conn, &quot;World&quot;)\n\n  // Receive some messages\n  assert Ok(Text(&quot;Hello&quot;)) = websocket.receive(conn, 500)\n  assert Ok(Text(&quot;World&quot;)) = websocket.receive(conn, 500)\n\n  // Close the connection\n  websocket.close(conn)\n}\n```\n\n## Testing this library\n\n```sh\npodman run --rm --detach -p 8080:8080 --name echo jmalloc/echo-server\ngleam test\n```\n","url":"index.html"},{"doc":"nerf/gun","title":"ConnectionPid","content":"pub external type ConnectionPid\n\n\nSynonyms:\nnerf/gun.ConnectionPid\nnerf/gun ConnectionPid","url":"nerf/gun.html#ConnectionPid"},{"doc":"nerf/gun","title":"Frame","content":"pub type Frame {\n  Close\n  Text(String)\n  Binary(BitString)\n  TextBuilder(StringBuilder)\n  BinaryBuilder(BitBuilder)\n}\n\nClose\n\n\nText(String)\n\n\nBinary(BitString)\n\n\nTextBuilder(StringBuilder)\n\n\nBinaryBuilder(BitBuilder)\n\n\nSynonyms:\nnerf/gun.Frame\nnerf/gun Frame","url":"nerf/gun.html#Frame"},{"doc":"nerf/gun","title":"StreamReference","content":"pub external type StreamReference\n\n\nSynonyms:\nnerf/gun.StreamReference\nnerf/gun StreamReference","url":"nerf/gun.html#StreamReference"},{"doc":"nerf/gun","title":"await_up","content":"pub external fn await_up(\n  ConnectionPid,\n) -&gt; Result(Dynamic, Dynamic)\n\nSynonyms:\nnerf/gun.await_up\nnerf/gun await_up","url":"nerf/gun.html#await_up"},{"doc":"nerf/gun","title":"open","content":"pub fn open(host: String, port: Int, opts_map: Dynamic) -&gt; Result(\n  ConnectionPid,\n  Dynamic,\n)\n\nSynonyms:\nnerf/gun.open\nnerf/gun open","url":"nerf/gun.html#open"},{"doc":"nerf/gun","title":"ws_send","content":"pub fn ws_send(pid: ConnectionPid, frame: Frame) -&gt; Nil\n\nSynonyms:\nnerf/gun.ws_send\nnerf/gun ws_send","url":"nerf/gun.html#ws_send"},{"doc":"nerf/gun","title":"ws_upgrade","content":"pub external fn ws_upgrade(\n  ConnectionPid,\n  String,\n  List(Header),\n) -&gt; StreamReference\n\nSynonyms:\nnerf/gun.ws_upgrade\nnerf/gun ws_upgrade","url":"nerf/gun.html#ws_upgrade"},{"doc":"nerf/gun","title":"nerf/gun","content":" Low level bindings to the gun API. You typically do not need to use this.\n Prefer the other modules in this library.","url":"nerf/gun.html"},{"doc":"nerf/websocket","title":"ConnectError","content":"pub type ConnectError {\n  ConnectionRefused(status: Int, headers: List(Header))\n  ConnectionFailed(reason: Dynamic)\n}\n The URI of the websocket server to connect to\nConnectionRefused(status: Int, headers: List(Header))\n\n\nConnectionFailed(reason: Dynamic)\n\n\nSynonyms:\nnerf/websocket.ConnectError\nnerf/websocket ConnectError","url":"nerf/websocket.html#ConnectError"},{"doc":"nerf/websocket","title":"Connection","content":"pub opaque type Connection\n\n\nSynonyms:\nnerf/websocket.Connection\nnerf/websocket Connection","url":"nerf/websocket.html#Connection"},{"doc":"nerf/websocket","title":"ConnectionOpts","content":"pub type ConnectionOpts {\n  Transport(Atom)\n  TransportOpts(List(ConnectionOptsTransportOpts))\n}\n\nTransport(Atom)\n\n\nTransportOpts(List(ConnectionOptsTransportOpts))\n\n\nSynonyms:\nnerf/websocket.ConnectionOpts\nnerf/websocket ConnectionOpts","url":"nerf/websocket.html#ConnectionOpts"},{"doc":"nerf/websocket","title":"ConnectionOptsTransportOpts","content":"pub type ConnectionOptsTransportOpts {\n  Verify(Atom)\n}\n\nVerify(Atom)\n\n\nSynonyms:\nnerf/websocket.ConnectionOptsTransportOpts\nnerf/websocket ConnectionOptsTransportOpts","url":"nerf/websocket.html#ConnectionOptsTransportOpts"},{"doc":"nerf/websocket","title":"Frame","content":"pub type Frame {\n  Close\n  Text(String)\n  Binary(BitString)\n}\n\nClose\n\n\nText(String)\n\n\nBinary(BitString)\n\n\nSynonyms:\nnerf/websocket.Frame\nnerf/websocket Frame","url":"nerf/websocket.html#Frame"},{"doc":"nerf/websocket","title":"close","content":"pub fn close(conn: Connection) -&gt; Nil\n\nSynonyms:\nnerf/websocket.close\nnerf/websocket close","url":"nerf/websocket.html#close"},{"doc":"nerf/websocket","title":"connect","content":"pub fn connect(hostname: String, path: String, port: Int, headers: List(\n    #(String, String),\n  ), opts: List(ConnectionOpts)) -&gt; Result(\n  Connection,\n  ConnectError,\n)\n\nSynonyms:\nnerf/websocket.connect\nnerf/websocket connect","url":"nerf/websocket.html#connect"},{"doc":"nerf/websocket","title":"receive","content":"pub external fn receive(\n  from: Connection,\n  within: Int,\n) -&gt; Result(Frame, Nil)\n\nSynonyms:\nnerf/websocket.receive\nnerf/websocket receive","url":"nerf/websocket.html#receive"},{"doc":"nerf/websocket","title":"send","content":"pub fn send(to conn: Connection, this message: String) -&gt; Nil\n\nSynonyms:\nnerf/websocket.send\nnerf/websocket send","url":"nerf/websocket.html#send"},{"doc":"nerf/websocket","title":"send_binary","content":"pub fn send_binary(to conn: Connection, this message: BitString) -&gt; Nil\n\nSynonyms:\nnerf/websocket.send_binary\nnerf/websocket send_binary","url":"nerf/websocket.html#send_binary"},{"doc":"nerf/websocket","title":"send_binary_builder","content":"pub fn send_binary_builder(to conn: Connection, this message: BitBuilder) -&gt; Nil\n\nSynonyms:\nnerf/websocket.send_binary_builder\nnerf/websocket send_binary_builder","url":"nerf/websocket.html#send_binary_builder"},{"doc":"nerf/websocket","title":"send_builder","content":"pub fn send_builder(to conn: Connection, this message: StringBuilder) -&gt; Nil\n\nSynonyms:\nnerf/websocket.send_builder\nnerf/websocket send_builder","url":"nerf/websocket.html#send_builder"},{"doc":"nerf/websocket","title":"nerf/websocket","content":"","url":"nerf/websocket.html"}]);